@@ -177,6 +177,7 @@ ConnectionsToLinks <- function(
 #'
 #' @param object A Seurat object
 #' @param peak.assay Name of assay containing peak information
+#' @param peak.slot Name of slot to pull chromatin data from
 #' @param expression.assay Name of assay containing gene expression information
 #' @param expression.slot Name of slot to pull expression data from
 #' @param gene.coords GRanges object containing coordinates of genes in the
@@ -187,8 +188,6 @@ ConnectionsToLinks <- function(
 #' @param min.cells Minimum number of cells positive for the peak and gene
 #' needed to include in the results.
 #' @param genes.use Genes to test. If NULL, determine from expression assay.
-#' @param method Which correlation coefficient to compute. Can be "pearson"
-#' (default), "spearman", or "kendall".
 #' @param n_sample Number of peaks to sample at random when computing the null
 #' distribution.
 #' @param pvalue_cutoff Minimum p-value required to retain a link. Links with a
@@ -227,12 +226,12 @@ LinkPeaks <- function(
   object,
   peak.assay,
   expression.assay,
+  peak.slot = "counts",
   expression.slot = "data",
   gene.coords = NULL,
   distance = 5e+05,
   min.distance = NULL,
   min.cells = 10,
-  method = "pearson",
   genes.use = NULL,
   n_sample = 200,
   pvalue_cutoff = 0.05,
@@ -269,18 +268,12 @@ LinkPeaks <- function(
          "Run RegionsStats before calling this function.")
   }
   peak.data <- GetAssayData(
-    object = object, assay = peak.assay, slot = 'counts'
+    object = object, assay = peak.assay, slot = peak.slot
   )
-  if (!("count" %in% colnames(x = meta.features))) {
-    # compute total count
-    hvf.info <- FindTopFeatures(object = peak.data)
-    hvf.info <- hvf.info[rownames(x = meta.features), ]
-    meta.features <- cbind(meta.features, hvf.info)
-  }
   expression.data <- GetAssayData(
     object = object, assay = expression.assay, slot = expression.slot
   )
-  peakcounts <- meta.features[rownames(x = peak.data), "count"]
+  peakcounts <- rowSums(x = peak.data > 0)
   genecounts <- rowSums(x = expression.data > 0)
   peaks.keep <- peakcounts > min.cells
   genes.keep <- genecounts > min.cells
